@@ -4,10 +4,10 @@ var NAVTREEINDEX0 =
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html":[2,0,0,0],
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html#a008e7eadae5e2d9521f271460e28ffde":[2,0,0,0,4],
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html#a4f685a39f94461879b57931d31a966d9":[2,0,0,0,5],
+"class_xml_rpc_handler_1_1_xml_rpc_handler.html#a61fca518f0b7c6f04e39d03f275b2e16":[2,0,0,0,1],
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html#a69e088cde25268cac42c6ca8c105cb6c":[2,0,0,0,6],
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html#a6bdd6715cce30b768fb1c3b1b24497d9":[2,0,0,0,2],
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html#a8e52f4706e7807d848384e8c86d3dca4":[2,0,0,0,3],
-"class_xml_rpc_handler_1_1_xml_rpc_handler.html#ac91c32a5345914cb98326f6886bd093e":[2,0,0,0,1],
 "class_xml_rpc_handler_1_1_xml_rpc_handler.html#ad72fdde48ffbc0779e17914f70ddc4e6":[2,0,0,0,0],
 "classes.html":[2,1],
 "functions.html":[2,2,0],
@@ -16,9 +16,9 @@ var NAVTREEINDEX0 =
 "index.html":[],
 "index.html":[0],
 "index.html#example":[0,1],
-"index.html#intro":[0,0],
-"namespace_xml_rpc_handler.html":[2,0,0],
+"index.html#xmlrpchandlerintro":[0,0],
 "namespace_xml_rpc_handler.html":[1,0,0],
+"namespace_xml_rpc_handler.html":[2,0,0],
 "namespaces.html":[1,0],
 "pages.html":[]
 };
