@@ -1,6 +1,7 @@
 var namespaceQore_1_1Xml =
 [
-    [ "Option", "namespaceQore_1_1Xml_1_1Option.html", null ],
+    [ "FileSaxIterator", "classQore_1_1Xml_1_1FileSaxIterator.html", "classQore_1_1Xml_1_1FileSaxIterator" ],
+    [ "SaxIterator", "classQore_1_1Xml_1_1SaxIterator.html", "classQore_1_1Xml_1_1SaxIterator" ],
     [ "XmlDoc", "classQore_1_1Xml_1_1XmlDoc.html", "classQore_1_1Xml_1_1XmlDoc" ],
     [ "XmlNode", "classQore_1_1Xml_1_1XmlNode.html", "classQore_1_1Xml_1_1XmlNode" ],
     [ "XmlReader", "classQore_1_1Xml_1_1XmlReader.html", "classQore_1_1Xml_1_1XmlReader" ],
